# R script to generate heatmap data from RPKM analysis of CAZy genes
# Lots of help from these two sites:
# https://bioconductor.statistik.tu-dortmund.de/packages/3.1/bioc/vignettes/ComplexHeatmap/inst/doc/ComplexHeatmap.html
# http://www.sthda.com/english/wiki/static-and-interactive-heatmap-in-r-unsupervised-machine-learning

# clear existing settings and data
rm(list=ls()) 

# required libraries
require(ComplexHeatmap)
#require(RColorBrewer)

data <- read.csv("Dropbox/Thrash_Lab/GoM_hypoxia_assemblies/Manuscript/mBio_draft2/cazy_gene_RPKM.csv", 
                 header=T, row.names = 1)

# Ignore text columns in the heatplot
dat.tmp <- data
dat.tmp$Bin <- NULL
dat.tmp$Family <- NULL
dat.tmp$Category <- NULL
dat.tmp$Group <- NULL

# Plot three separate layers- the heatplot, the system annotations, and the bin designations
Heatmap(dat.tmp, 
        width = unit(8, "cm"),
        name = "Gene RPKM",
        row_names_side = "left", row_names_gp = gpar(fontsize = 4),
        col = colorRampPalette(c("lightyellow", "red"))(52),
        #column_title = "Samples", column_title_side = "bottom",
        #row_title = "Gene RPKM",
        cluster_rows = FALSE, cluster_columns = FALSE,
        split = data$Group, combined_name_fun = NULL
        ) +
Heatmap(data$Category, 
        name="CAZy", 
        col=c("CE"="green", "GH"="yellow", "GT"="purple", "CBM"="orange", "NA"="black"),
        width = unit(6, "mm")
        ) +
Heatmap(data$Group, 
        name="Group",
        col=c("MGII"="dark green","SAR202"="grey","SAR406"="blue"),
        width = unit(6, "mm")
        )
